@@ -6,27 +6,27 @@ const Main = imports.ui.main;
 const Overview = imports.ui.overview;
 const { WorkspacesDisplay } = imports.ui.workspacesView;
 
-let MyWorkspacesDisplay = class extends WorkspacesDisplay {
-    constructor() {
-        super();
+let MyWorkspacesDisplay = GObject.registerClass(
+class MyWorkspacesDisplay extends WorkspacesDisplay {
+    _init() {
+        super._init();
 
-        this.actor.add_constraint(
+        this.add_constraint(
             new Layout.MonitorConstraint({
                 primary: true,
-                work_area: true
+                work_area: true,
             }));
 
-        this.actor.connect('destroy', this._onDestroy.bind(this));
-
         this._workareasChangedId = global.display.connect('workareas-changed',
             this._onWorkAreasChanged.bind(this));
         this._onWorkAreasChanged();
     }
 
     show(...args) {
-        if (this._scrollEventId == 0)
+        if (!this._scrollEventId) {
             this._scrollEventId = Main.windowPicker.connect('scroll-event',
                 this._onScrollEvent.bind(this));
+        }
 
         super.show(...args);
     }
@@ -49,8 +49,8 @@ let MyWorkspacesDisplay = class extends WorkspacesDisplay {
         super._updateWorkspacesViews();
 
         this._workspacesViews.forEach(v => {
-            Main.layoutManager.overviewGroup.remove_actor(v.actor);
-            Main.windowPicker.add_actor(v.actor);
+            Main.layoutManager.overviewGroup.remove_actor(v);
+            Main.windowPicker.add_actor(v);
         });
     }
 
@@ -58,14 +58,15 @@ let MyWorkspacesDisplay = class extends WorkspacesDisplay {
         if (this._workareasChangedId)
             global.display.disconnect(this._workareasChangedId);
         this._workareasChangedId = 0;
+
+        super._onDestroy();
     }
-};
+});
 
 var WindowPicker = GObject.registerClass({
-    GTypeName: 'WindowListWindowPicker',
     Signals: {
-        'open-state-changed': { param_types: [GObject.TYPE_BOOLEAN] }
-    }
+        'open-state-changed': { param_types: [GObject.TYPE_BOOLEAN] },
+    },
 }, class extends Clutter.Actor {
     _init() {
         this._visible = false;
@@ -97,7 +98,7 @@ var WindowPicker = GObject.registerClass({
         Main.overview.addAction = a => this._backgroundGroup.add_action(a);
 
         this._workspacesDisplay = new MyWorkspacesDisplay();
-        this.add_child(this._workspacesDisplay.actor);
+        this.add_child(this._workspacesDisplay);
 
         Main.overview.addAction = addActionOrig;
 
@@ -140,7 +141,7 @@ var WindowPicker = GObject.registerClass({
         this._stageKeyPressId = global.stage.connect('key-press-event',
             (a, event) => {
                 let sym = event.get_key_symbol();
-                if (sym == Clutter.KEY_Escape) {
+                if (sym === Clutter.KEY_Escape) {
                     this.close();
                     return Clutter.EVENT_STOP;
                 }
@@ -173,12 +174,12 @@ var WindowPicker = GObject.registerClass({
     }
 
     _fakeOverviewAnimation(onComplete) {
-        Main.overview.animationInProgress = true;
+        Main.overview._animationInProgress = true;
         GLib.timeout_add(
             GLib.PRIORITY_DEFAULT,
             Overview.ANIMATION_TIME,
             () => {
-                Main.overview.animationInProgress = false;
+                Main.overview._animationInProgress = false;
                 if (onComplete)
                     onComplete();
             });
@@ -186,7 +187,7 @@ var WindowPicker = GObject.registerClass({
 
     _fakeOverviewVisible(visible) {
         // Fake overview state for WorkspacesDisplay
-        Main.overview.visible = visible;
+        Main.overview._visible = visible;
 
         // Hide real windows
         Main.layoutManager._inOverview = visible;
@@ -199,7 +200,7 @@ var WindowPicker = GObject.registerClass({
                 return true;
 
             this._modal = Main.pushModal(this, {
-                actionMode: Shell.ActionMode.OVERVIEW
+                actionMode: Shell.ActionMode.OVERVIEW,
             });
 
             if (!this._modal) {
@@ -244,7 +245,7 @@ var WindowPickerToggle = GObject.registerClass(
 class WindowPickerToggle extends St.Button {
     _init() {
         let iconBin = new St.Widget({
-            layout_manager: new Clutter.BinLayout()
+            layout_manager: new Clutter.BinLayout(),
         });
         iconBin.add_child(new St.Icon({
             icon_name: 'focus-windows-symbolic',
@@ -252,7 +253,7 @@ class WindowPickerToggle extends St.Button {
             x_expand: true,
             y_expand: true,
             x_align: Clutter.ActorAlign.CENTER,
-            y_align: Clutter.ActorAlign.CENTER
+            y_align: Clutter.ActorAlign.CENTER,
         }));
         super._init({
             style_class: 'window-picker-toggle',
@@ -260,7 +261,7 @@ class WindowPickerToggle extends St.Button {
             visible: !Main.sessionMode.hasOverview,
             x_fill: true,
             y_fill: true,
-            toggle_mode: true
+            toggle_mode: true,
         });
 
         this.connect('notify::checked', () => {
